@@ -36,3 +36,10 @@ class OptionalListOfExpandedProcedures(BaseModel):
     procedures: Optional[List[ProcedureDataSchema]] = Field(
         None, description="Multiple procedures data. (Optional)"
     )
+
+
+class RecommendationSchema(BaseModel):
+    primary: List[ProcedureDataDTO] = Field(..., description="Primary recommendations")
+    alternatives: List[ProcedureDataDTO] = Field(
+        ..., description="Alternative recommendations"
+    )
