@@ -10,5 +10,5 @@ class ReadSingleParameter(
     pass
 
 
-class GenerateSuggestion(BaseModel):
+class GenerateRecommendation(BaseModel):
     overall_plan: str = Field(..., description="Overall plan")
